@@ -284,7 +284,7 @@ class SizeMapping(SemanticMapping):
 
             if map_type == "numeric":
 
-                levels, lookup_table, norm = self.numeric_mapping(
+                levels, lookup_table, norm, size_range = self.numeric_mapping(
                     data, sizes, norm,
                 )
 
@@ -295,6 +295,7 @@ class SizeMapping(SemanticMapping):
                 levels, lookup_table = self.categorical_mapping(
                     data, sizes, order,
                 )
+                size_range = None
 
             # --- Option 3: datetime mapping
 
@@ -306,11 +307,13 @@ class SizeMapping(SemanticMapping):
                     # pandas and numpy represent datetime64 data
                     list(data), sizes, order,
                 )
+                size_range = None
 
             self.map_type = map_type
             self.levels = levels
             self.norm = norm
             self.sizes = sizes
+            self.size_range = size_range
             self.lookup_table = lookup_table
 
     def infer_map_type(self, norm, sizes, var_type):
@@ -332,9 +335,7 @@ class SizeMapping(SemanticMapping):
             normed = self.norm(key)
             if np.ma.is_masked(normed):
                 normed = np.nan
-            size_values = self.lookup_table.values()
-            size_range = min(size_values), max(size_values)
-            value = size_range[0] + normed * np.ptp(size_range)
+            value = self.size_range[0] + normed * np.ptp(self.size_range)
         return value
 
     def categorical_mapping(self, data, sizes, order):
@@ -383,7 +384,7 @@ class SizeMapping(SemanticMapping):
                 # across the visual representation of the data. But at this
                 # point, we don't know the visual representation. Likely we
                 # want to change the logic of this Mapping so that it gives
-                # points on a nornalized range that then gets unnormalized
+                # points on a normalized range that then gets un-normalized
                 # when we know what we're drawing. But given the way the
                 # package works now, this way is cleanest.
                 sizes = self.plotter._default_size_range
@@ -391,7 +392,7 @@ class SizeMapping(SemanticMapping):
             # For categorical sizes, use regularly-spaced linear steps
             # between the minimum and maximum sizes. Then reverse the
             # ramp so that the largest value is used for the first entry
-            # in size_order, etc. This is because "ordered" categoricals
+            # in size_order, etc. This is because "ordered" categories
             # are often though to go in decreasing priority.
             sizes = np.linspace(*sizes, len(levels))[::-1]
             lookup_table = dict(zip(levels, sizes))
@@ -435,7 +436,7 @@ class SizeMapping(SemanticMapping):
 
                 # When not provided, we get the size range from the plotter
                 # object we are attached to. See the note in the categorical
-                # method about how this is suboptimal for future development.:
+                # method about how this is suboptimal for future development.
                 size_range = self.plotter._default_size_range
 
         # Now that we know the minimum and maximum sizes that will get drawn,
@@ -475,7 +476,7 @@ class SizeMapping(SemanticMapping):
             sizes = lo + sizes_scaled * (hi - lo)
             lookup_table = dict(zip(levels, sizes))
 
-        return levels, lookup_table, norm
+        return levels, lookup_table, norm, size_range
 
 
 @share_init_params_with_map
@@ -871,28 +872,43 @@ class VectorPlotter:
         # The caller will determine the order of variables in plot_data
         for key, val in kwargs.items():
 
-            if isinstance(val, (str, bytes)):
-                # String inputs trigger __getitem__
+            # First try to treat the argument as a key for the data collection.
+            # But be flexible about what can be used as a key.
+            # Usually it will be a string, but allow numbers or tuples too when
+            # taking from the main data object. Only allow strings to reference
+            # fields in the index, because otherwise there is too much ambiguity.
+            try:
+                val_as_data_key = (
+                    val in data
+                    or (isinstance(val, (str, bytes)) and val in index)
+                )
+            except (KeyError, TypeError):
+                val_as_data_key = False
+
+            if val_as_data_key:
+
+                # We know that __getitem__ will work
+
                 if val in data:
-                    # First try to get an entry in the data object
                     plot_data[key] = data[val]
-                    variables[key] = val
                 elif val in index:
-                    # Failing that, try to get an entry in the index object
                     plot_data[key] = index[val]
-                    variables[key] = val
-                else:
-                    # We don't know what this name means
-                    err = f"Could not interpret value `{val}` for parameter `{key}`"
-                    raise ValueError(err)
+                variables[key] = val
+
+            elif isinstance(val, (str, bytes)):
+
+                # This looks like a column name but we don't know what it means!
+
+                err = f"Could not interpret value `{val}` for parameter `{key}`"
+                raise ValueError(err)
 
             else:
 
-                # Otherwise, assume the value is itself a vector of data
+                # Otherwise, assume the value is itself data
 
-                # Raise when data is present and a vector can't be combined with it
+                # Raise when data object is present and a vector can't matched
                 if isinstance(data, pd.DataFrame) and not isinstance(val, pd.Series):
-                    if val is not None and len(data) != len(val):
+                    if np.ndim(val) and len(data) != len(val):
                         val_cls = val.__class__.__name__
                         err = (
                             f"Length of {val_cls} vectors must match length of `data`"
@@ -1033,10 +1049,16 @@ class VectorPlotter:
                     ax = self.ax
                 axis = getattr(ax, f"{var}axis")
 
-                comp_var = axis.convert_units(self.plot_data[var])
+                # Use the converter assigned to the axis to get a float representation
+                # of the data, passing np.nan or pd.NA through (pd.NA becomes np.nan)
+                with pd.option_context('mode.use_inf_as_null', True):
+                    orig = self.plot_data[var].dropna()
+                comp_col = pd.Series(index=orig.index, dtype=float, name=var)
+                comp_col.loc[orig.index] = pd.to_numeric(axis.convert_units(orig))
+
                 if axis.get_scale() == "log":
-                    comp_var = np.log10(comp_var)
-                comp_data.insert(0, var, comp_var)
+                    comp_col = np.log10(comp_col)
+                comp_data.insert(0, var, comp_col)
 
             self._comp_data = comp_data
 
@@ -1177,28 +1199,32 @@ class VectorPlotter:
 
 
 def variable_type(vector, boolean_type="numeric"):
-    """Determine whether a vector contains numeric, categorical, or dateime data.
+    """
+    Determine whether a vector contains numeric, categorical, or datetime data.
 
     This function differs from the pandas typing API in two ways:
 
     - Python sequences or object-typed PyData objects are considered numeric if
       all of their entries are numeric.
     - String or mixed-type data are considered categorical even if not
-      explicitly represented as a :class:pandas.api.types.CategoricalDtype`.
+      explicitly represented as a :class:`pandas.api.types.CategoricalDtype`.
 
     Parameters
     ----------
     vector : :func:`pandas.Series`, :func:`numpy.ndarray`, or Python sequence
         Input data to test.
-    binary_type : 'numeric' or 'categorical'
+    boolean_type : 'numeric' or 'categorical'
         Type to use for vectors containing only 0s and 1s (and NAs).
 
     Returns
     -------
     var_type : 'numeric', 'categorical', or 'datetime'
         Name identifying the type of data in the vector.
-
     """
+    # If a categorical dtype is set, infer categorical
+    if pd.api.types.is_categorical_dtype(vector):
+        return "categorical"
+
     # Special-case all-na data, which is always "numeric"
     if pd.isna(vector).all():
         return "numeric"
@@ -1222,9 +1248,6 @@ def variable_type(vector, boolean_type="numeric"):
     if pd.api.types.is_numeric_dtype(vector):
         return "numeric"
 
-    if pd.api.types.is_categorical_dtype(vector):
-        return "categorical"
-
     if pd.api.types.is_datetime64_dtype(vector):
         return "datetime"
 
@@ -1265,8 +1288,8 @@ def infer_orient(x=None, y=None, orient=None, require_numeric=True):
     variable. Practically, this is used when determining the axis for
     numerical aggregation.
 
-    Paramters
-    ---------
+    Parameters
+    ----------
     x, y : Vector data or None
         Positional data vectors for the plot.
     orient : string or None
